<?php

/**
 * @module          Contacts
 * @author          cms-lab
 * @copyright       2020-2021 cms-lab
 * @link            https://cms-lab.com
 * @license         Custom License
 * @license_terms   see license
 *
 */
 
class contacts extends LEPTON_abstract
{
	public $addon_color = '';
	public $action_url = LEPTON_URL;
	public $photo_url = LEPTON_URL;
	public $contacts = array();
	public $contact_groups = array();
	public $database = 0;
	public $admin = 0;	
	public $support_link = "<a href='#'>NO Live-Support / FAQ</a>";
	public $readme_link = "<a href='https://cms-lab.com/_documentation/contacts/readme.php' class='info' target='_blank'>Readme</a>";
	
	public static $instance;

public function initialize() 
	{	
		$this->database = LEPTON_database::getInstance();
		$this->admin = LEPTON_admin::getInstance();			
		$this->action_url = ADMIN_URL . '/admintools/tool.php?tool=contacts';
		$this->photo_url = LEPTON_URL.MEDIA_DIRECTORY.'/contacts/';		
		$this->addon_color = 'blue';
		$this->init_tool();
		
	}

public function init_tool( $sToolname = '' )
	{
		//get all contacts
		$this->database->execute_query(
			"SELECT * FROM ".TABLE_PREFIX."mod_contacts ORDER BY name2" ,
			true,
			$this->contacts,
			true
		);		

		//get all groups
		$this->database->execute_query(
			"SELECT * FROM ".TABLE_PREFIX."mod_contacts_groups " ,
			true,
			$this->contact_groups,
			true
		);

	}
	
	public function list_groups() 
	{

		
		// data for twig template engine	
		$data = array(
			'oCBE'		=> $this,						
			'leptoken'	=> get_leptoken()		

		);

		//	get the template-engine
		$oTwig = lib_twig_box::getInstance();
		$oTwig->registerModule('contacts');
				
		echo $oTwig->render( 
			"@contacts/list_groups.lte",	//	template-filename
			$data						//	template-data
		);			
	}
	
	public function delete_group($id) 
	{
		if (is_numeric($id)  && $id > 0 )			
		{
			$to_delete = intval($id);
			
			$this->database->simple_query("DELETE FROM ".TABLE_PREFIX."mod_contacts_groups WHERE group_id = ".$to_delete);					
			$this->admin->print_success($this->language['delete_ok'], $this->action_url);			
		}		
	}		

	public function edit_group($id) 
	{
		if (is_numeric($id)  && $id == -1 )
		{
			$fields = array(
				'group_name' => 'New Group'
			);
			
			$result = $this->database->build_and_execute (
				"INSERT",
				TABLE_PREFIX."mod_contacts_groups",
				$fields
			);

			$this->admin->print_success($this->language['save_ok'], $this->action_url);
		}		
		elseif (is_numeric($id) && $id > 0 )
		{
			$group_id = intval($id);
			$current_group = array();
			$this->database->execute_query(
				"SELECT * FROM ".TABLE_PREFIX."mod_contacts_groups WHERE group_id = ".$group_id ,
				true,
				$current_group,
				false
			);		
				
			// data for twig template engine	
			$data = array(
				'oCBE'			=> $this,
				'current_group'=> $current_group,
				'leptoken'		=> get_leptoken()
			);

			/**	
			 *	get the template-engine.
			 */
			$oTwig = lib_twig_box::getInstance();
			$oTwig->registerModule('contacts');
					
			echo $oTwig->render( 
				"@contacts/edit_group.lte",	//	template-filename
				$data					//	template-data
			);				
		}
	}

	public function save_group($id) 
	{
		if (is_numeric($id)  && $id > 0 )			
		{
			$group_id = intval($id);
			
			$request = LEPTON_request::getInstance();
			$all_names = array (
				'group_name'=> array ('type' => 'string_clean', 'default' => ""),
				'active'	=> array ('type' => 'int', 'default' => "1")
			);		

			$all_values = $request->testPostValues($all_names);			
			$table = TABLE_PREFIX."mod_contacts_groups";
			$this->database->build_and_execute( 'UPDATE', $table, $all_values,'group_id = '.$group_id);
			
			$this->admin->print_success($this->language['save_ok'], $this->action_url);
		}		
	}

	
	public function list_contacts() 
	{	
		// data for twig template engine	
		$data = array(
			'oCBE'		=> $this,						
			'leptoken'	=> get_leptoken()		

		);

		//	get the template-engine
		$oTwig = lib_twig_box::getInstance();
		$oTwig->registerModule('contacts');
				
		echo $oTwig->render( 
			"@contacts/list_contacts.lte",	//	template-filename
			$data						//	template-data
		);			
	}
	
	
	public function edit_contact($id = 0) 
	{
		if (is_numeric($id)  && $id == -1 )
		{
			$fields = array(
				'name2' => 'AA-Name2'
			);
			
			$this->database->build_and_execute (
				"INSERT",
				TABLE_PREFIX."mod_contacts",
				$fields
			);

			$this->admin->print_success($this->language['save_ok'], $this->action_url);
		}
		elseif($_POST['edit_contact'] > 0)
		{
			$id = intval($_POST['edit_contact']);
			
			$current_contact = array();
			$this->database->execute_query(
				"SELECT * FROM ".TABLE_PREFIX."mod_contacts WHERE id = ".$id ,
				true,
				$current_contact,
				false
			);

			$active_groups = array();
			$this->database->execute_query(
				"SELECT * FROM ".TABLE_PREFIX."mod_contacts_groups WHERE active = 1" ,
				true,
				$active_groups,
				true
			);			
		
			// data for twig template engine	
			$data = array(
				'oCBE'			=> $this,
				'leptoken'		=> get_leptoken(),
				'active_groups'	=> $active_groups,
				'current_contact'	=> $current_contact
				);

			/**	
			 *	get the template-engine.
			 */
			$oTwig = lib_twig_box::getInstance();
			$oTwig->registerModule('contacts');
				
			echo $oTwig->render( 
				"@contacts/edit_contact.lte",	//	template-filename
				$data						//	template-data
			);
		}
	}		


	
	public function export_vcard($id = 0) 
	{	
		if($_POST['export_vcard'] > 0)
			{
				$id = intval($_POST['export_vcard']);
					
				$this->admin->print_success($this->language['save_ok'], $this->action_url);
			}
	}
	
	
	public function delete_contact($id = 0) 
	{	
		if($_POST['delete_contact'] > 0)
			{
				$id = intval($_POST['delete_contact']);			
				$this->database->simple_query("DELETE FROM ".TABLE_PREFIX."mod_contacts WHERE id = ".$id);				
					
				$this->admin->print_success($this->language['save_ok'], $this->action_url);
			}
	}

	public function save_contact($id) 
	{
		if (is_numeric($id)  && $id > 0 )			
		{
			$contact_id = intval($id);
		
			$request = LEPTON_request::getInstance();
			$all_names = array (
				'id'		=> array ('type' => 'integer', 'default' => "1"),
				'name1'		=> array ('type' => 'string_clean', 'default' => ""),
				'name2'		=> array ('type' => 'string_clean', 'default' => ""),
				'photo'		=> array ('type' => 'string_clean', 'default' => "image.png"),
				'group_id'	=> array ('type' => 'integer', 'default' => "0"),
				'role'		=> array ('type' => 'string_clean', 'default' => ""),
				'office_extension'	=> array ('type' => 'string_clean', 'default' => ""),
				'office_street'		=> array ('type' => 'string_clean', 'default' => ""),
				'office_zip'		=> array ('type' => 'string_clean', 'default' => ""),
				'office_city'		=> array ('type' => 'string_clean', 'default' => ""),
				'office_country'	=> array ('type' => 'string_clean', 'default' => ""),
				'office_fon'		=> array ('type' => 'string_clean', 'default' => ""),
				'office_mobile'		=> array ('type' => 'string_clean', 'default' => ""),
				'office_email1'		=> array ('type' => 'string_clean', 'default' => ""),
				'office_email2'		=> array ('type' => 'string_clean', 'default' => ""),
				'office_www'		=> array ('type' => 'string_clean', 'default' => ""),
				'office_memo'		=> array ('type' => 'string_clean', 'default' => ""),
				'private_extension'	=> array ('type' => 'string_clean', 'default' => "Privat"),
				'private_street'	=> array ('type' => 'string_clean', 'default' => ""),
				'private_zip'		=> array ('type' => 'string_clean', 'default' => ""),
				'private_city'		=> array ('type' => 'string_clean', 'default' => ""),
				'private_country'	=> array ('type' => 'string_clean', 'default' => ""),
				'private_fon'		=> array ('type' => 'string_clean', 'default' => ""),
				'private_mobile'	=> array ('type' => 'string_clean', 'default' => ""),
				'private_email'		=> array ('type' => 'string_clean', 'default' => ""),
				'private_www'		=> array ('type' => 'string_clean', 'default' => ""),
				'private_memo'		=> array ('type' => 'string_clean', 'default' => ""),
				'active'			=> array ('type' => 'integer', 'default' => "1")
			);		

			$all_values = $request->testPostValues($all_names);			
			$table = TABLE_PREFIX."mod_contacts";
			$this->database->build_and_execute( 'UPDATE', $table, $all_values,'id = '.$contact_id);
			
			$this->admin->print_success($this->language['save_ok'], $this->action_url);			
		}		
	}	

	
	public function show_info() 
	{

		// data for twig template engine	
		$data = array(
			'oCBE'			=> $this,				
			'image_url'		=> 'https://cms-lab.com/_documentation/media/contacts/contacts.jpg'
			);

		/**	
		 *	get the template-engine.
		 */
		$oTwig = lib_twig_box::getInstance();
		$oTwig->registerModule('contacts');
			
		echo $oTwig->render( 
			"@contacts/info.lte",	//	template-filename
			$data					//	template-data
		);	
	}	
 } // end class
